==> grizzly-http-2.0.1-sources.jar: org/glassfish/grizzly/http/HttpResponsePacketImpl.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2010-2011 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package org.glassfish.grizzly.http;

import org.glassfish.grizzly.ThreadCache;
import org.glassfish.grizzly.http.HttpCodecFilter.ContentParsingState;

/**
 *
 * @author oleksiys
 */
class HttpResponsePacketImpl extends HttpResponsePacket implements HttpPacketParsing {
    private static final ThreadCache.CachedTypeIndex<HttpResponsePacketImpl> CACHE_IDX =
            ThreadCache.obtainIndex(HttpResponsePacketImpl.class, 16);

    public static HttpResponsePacketImpl create() {
        final HttpResponsePacketImpl httpResponseImpl =
                ThreadCache.takeFromCache(CACHE_IDX);
        if (httpResponseImpl != null) {
            return httpResponseImpl;
        }

        return new HttpResponsePacketImpl();
    }

    private boolean isHeaderParsed;
    
    private final HttpCodecFilter.HeaderParsingState headerParsingState;
    private final HttpCodecFilter.ContentParsingState contentParsingState;

    private HttpResponsePacketImpl() {
        this.headerParsingState = new HttpCodecFilter.HeaderParsingState();
        this.contentParsingState = new HttpCodecFilter.ContentParsingState();
    }

    public void initialize(final HttpCodecFilter filter,
                           final int initialOffset,
                           final int maxHeaderSize) {
        headerParsingState.initialize(filter, initialOffset, maxHeaderSize);
    }
    
    @Override
    public HttpCodecFilter.HeaderParsingState getHeaderParsingState() {
        return headerParsingState;
    }

    @Override
    public ContentParsingState getContentParsingState() {
        return contentParsingState;
    }

    @Override
    public ProcessingState getProcessingState() {
        return getRequest().getProcessingState();
    }

    @Override
    public boolean isHeaderParsed() {
        return isHeaderParsed;
    }

    @Override
    public void setHeaderParsed(boolean isHeaderParsed) {
        this.isHeaderParsed = isHeaderParsed;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    protected void reset() {
        headerParsingState.recycle();
        contentParsingState.recycle();
        isHeaderParsed = false;
        super.reset();
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public void recycle() {
        if (getRequest().isExpectContent()) {
            return;
        }
        reset();
        ThreadCache.putToCache(CACHE_IDX, this);
    }
}

==> grizzly-http-2.2.11-sources.jar: org/glassfish/grizzly/http/HttpResponsePacketImpl.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2010-2012 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package org.glassfish.grizzly.http;

import org.glassfish.grizzly.ThreadCache;
import org.glassfish.grizzly.http.HttpCodecFilter.ContentParsingState;

/**
 *
 * @author oleksiys
 */
class HttpResponsePacketImpl extends HttpResponsePacket implements HttpPacketParsing {
    private static final ThreadCache.CachedTypeIndex<HttpResponsePacketImpl> CACHE_IDX =
            ThreadCache.obtainIndex(HttpResponsePacketImpl.class, 16);

    public static HttpResponsePacketImpl create() {
        final HttpResponsePacketImpl httpResponseImpl =
                ThreadCache.takeFromCache(CACHE_IDX);
        if (httpResponseImpl != null) {
            return httpResponseImpl;
        }

        return new HttpResponsePacketImpl();
    }

    private boolean isHeaderParsed;
    
    private final HttpCodecFilter.HeaderParsingState headerParsingState;
    private final HttpCodecFilter.ContentParsingState contentParsingState;

    private HttpResponsePacketImpl() {
        this.headerParsingState = new HttpCodecFilter.HeaderParsingState();
        this.contentParsingState = new HttpCodecFilter.ContentParsingState();
    }

    public void initialize(final HttpCodecFilter filter,
                           final int initialOffset,
                           final int maxHeaderSize,
                           final int maxNumberOfHeaders) {
        headerParsingState.initialize(filter, initialOffset, maxHeaderSize);
        headers.setMaxNumHeaders(maxNumberOfHeaders);
        contentParsingState.trailerHeaders.setMaxNumHeaders(maxNumberOfHeaders);
    }
    
    @Override
    public HttpCodecFilter.HeaderParsingState getHeaderParsingState() {
        return headerParsingState;
    }

    @Override
    public ContentParsingState getContentParsingState() {
        return contentParsingState;
    }

    @Override
    public ProcessingState getProcessingState() {
        return getRequest().getProcessingState();
    }

    @Override
    public boolean isHeaderParsed() {
        return isHeaderParsed;
    }

    @Override
    public void setHeaderParsed(boolean isHeaderParsed) {
        this.isHeaderParsed = isHeaderParsed;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    protected void reset() {
        headerParsingState.recycle();
        contentParsingState.recycle();
        isHeaderParsed = false;
        super.reset();
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public void recycle() {
        if (getRequest().isExpectContent()) {
            return;
        }
        reset();
        ThreadCache.putToCache(CACHE_IDX, this);
    }
}
